@@ -15,7 +15,7 @@
 #
 #=============================================================================
 
-package Term::CLI::L10N::nl 0.059000;
+package Term::CLI::L10N::nl 0.060000;
 
 use 5.014;
 use warnings;
@@ -169,7 +169,7 @@ msgstr "te lang (max. lengte %1)"
 #: lib/Term/CLI/Command/Help.pm
 msgid ""
 "Show help for any given command sequence (or a command\n"
-"overview if no argument is given.\n\n"
+"overview if no argument is given).\n\n"
 "The C<--pod> (C<-p>) option will cause raw POD\n"
 "to be shown.\n\n"
 "The C<--all> (C<-a>) option will list help text for all commands."
@@ -299,7 +299,7 @@ Term::CLI::L10N::nl - Dutch localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.059000
+version 0.060000
 
 =head1 SYNOPSIS
 
